pub struct DeployPlugin { /* private fields */ }Expand description
Plugin that generates deployment configuration files.
Implementations
Sourceimpl DeployPlugin
impl DeployPlugin
Sourcepub const fn new(target: DeployTarget) -> Self
pub const fn new(target: DeployTarget) -> Self
Creates a new DeployPlugin for the given target.
Examples
use ssg::deploy::{DeployPlugin, DeployTarget};
use ssg::plugin::Plugin;
let p = DeployPlugin::new(DeployTarget::Netlify);
assert_eq!(p.name(), "deploy");Trait Implementations
Sourceimpl Clone for DeployPlugin
impl Clone for DeployPlugin
Sourcefn clone(&self) -> DeployPlugin
fn clone(&self) -> DeployPlugin
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for DeployPlugin
Sourceimpl Debug for DeployPlugin
impl Debug for DeployPlugin
Sourceimpl Plugin for DeployPlugin
impl Plugin for DeployPlugin
Sourcefn after_compile(&self, ctx: &PluginContext) -> Result<(), SsgError>
fn after_compile(&self, ctx: &PluginContext) -> Result<(), SsgError>
Called after site compilation completes. Read more
Sourcefn before_compile(&self, _ctx: &PluginContext) -> Result<(), SsgError>
fn before_compile(&self, _ctx: &PluginContext) -> Result<(), SsgError>
Called before site compilation begins. Read more
Sourcefn transform_html(
&self,
html: &str,
_path: &Path,
_ctx: &PluginContext,
) -> Result<String, SsgError>
fn transform_html( &self, html: &str, _path: &Path, _ctx: &PluginContext, ) -> Result<String, SsgError>
Per-file HTML transform hook — called once per HTML file during
the fused transform pass. Read more
Sourcefn has_transform(&self) -> bool
fn has_transform(&self) -> bool
Returns
true if this plugin implements transform_html.
Override to true to opt in to the fused transform pass.Sourcefn needs_all_files(&self) -> bool
fn needs_all_files(&self) -> bool
Returns
true if this plugin must always observe the full
cache.html_files() list — even during --incremental
rebuilds that only invalidated a handful of pages. Read moreAuto Trait Implementations
impl Freeze for DeployPlugin
impl RefUnwindSafe for DeployPlugin
impl Send for DeployPlugin
impl Sync for DeployPlugin
impl Unpin for DeployPlugin
impl UnsafeUnpin for DeployPlugin
impl UnwindSafe for DeployPlugin